@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: bug_report_page.php,v 1.44 2004/08/17 18:01:18 thraxisp Exp $
+	# $Id: bug_report_page.php,v 1.48 2004/10/24 19:28:46 thraxisp Exp $
 	# --------------------------------------------------------
 
 	# This file POSTs data to report_bug.php
@@ -204,7 +204,7 @@
 		<span class="required">*</span><?php echo lang_get( 'summary' ) ?> <?php print_documentation_link( 'summary' ) ?>
 	</td>
 	<td>
-		<input tabindex="5" type="text" name="summary" size="60" maxlength="128" value="<?php echo $f_summary ?>" />
+		<input tabindex="5" type="text" name="summary" size="105" maxlength="128" value="<?php echo $f_summary ?>" />
 	</td>
 </tr>
 
@@ -215,7 +215,7 @@
 		<span class="required">*</span><?php echo lang_get( 'description' ) ?> <?php print_documentation_link( 'description' ) ?>
 	</td>
 	<td>
-		<textarea tabindex="6" name="description" cols="60" rows="5" wrap="virtual"><?php echo $f_description ?></textarea>
+		<textarea tabindex="6" name="description" cols="80" rows="10" wrap="virtual"><?php echo $f_description ?></textarea>
 	</td>
 </tr>
 
@@ -226,7 +226,7 @@
 		<?php echo lang_get( 'additional_information' ) ?> <?php print_documentation_link( 'additional_information' ) ?>
 	</td>
 	<td>
-		<textarea tabindex="7" name="additional_info" cols="60" rows="5" wrap="virtual"><?php echo $f_additional_info ?></textarea>
+		<textarea tabindex="7" name="additional_info" cols="80" rows="10" wrap="virtual"><?php echo $f_additional_info ?></textarea>
 	</td>
 </tr>
 
@@ -272,13 +272,16 @@
 
 
 <!-- File Upload (if enabled) -->
-<?php if ( file_allow_bug_upload() ) { ?>
+<?php if ( file_allow_bug_upload() ) { 
+	$t_max_file_size = (int)min( ini_get_number( 'upload_max_filesize' ), ini_get_number( 'post_max_size' ), config_get( 'max_file_size' ) );
+?>
 <tr <?php echo helper_alternate_class() ?>>
 	<td class="category">
 		<?php echo lang_get( 'upload_file' ) ?>
+		<?php echo '<span class="small">(' . lang_get( 'max_file_size' ) . ': ' . number_format( $t_max_file_size/1000 ) . 'k)</span>'?>
 	</td>
 	<td>
-		<input type="hidden" name="max_file_size" value="<?php echo config_get( 'max_file_size' ) ?>" />
+		<input type="hidden" name="max_file_size" value="<?php echo $t_max_file_size ?>" />
 		<input tabindex="8" name="file" type="file" size="60" />
 	</td>
 </tr>
@@ -304,6 +307,23 @@
 	</td>
 </tr>
 
+<!-- Relationship (in case of cloned bug creation...) -->
+<?php
+	if( $f_master_bug_id > 0 ) {
+?>
+<tr <?php echo helper_alternate_class() ?>>
+	<td class="category">
+		<?php echo lang_get( 'relationship_with_parent' ) ?>
+	</td>
+	<td>
+		<?php relationship_list_box_for_cloned_bug( BUG_BLOCKS ) ?>
+		<?php PRINT '<b>' . lang_get( 'bug' ) . ' ' . bug_format_id( $f_master_bug_id ) . '</b>' ?>
+	</td>
+</tr>
+<?php
+	}
+?>
+
 <!-- Report Stay (report more bugs) -->
 <tr <?php echo helper_alternate_class() ?>>
 	<td class="category">
