@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: config_defaults_inc.php,v 1.206 2004/09/12 12:12:30 vboctor Exp $
+	# $Id: config_defaults_inc.php,v 1.225 2004/12/11 07:21:51 vboctor Exp $
 	# --------------------------------------------------------
 
 
@@ -32,8 +32,12 @@
 	# --- database variables ---------
 
 	# set these values to match your setup
+
+	# hostname should be either a hostname or connection string to supply to adodb.
+	# For example, if you would like to connect to a mysql server on the local machine,
+	# set hostname to 'localhost', and db_type to 'mysql'.
+	# If you need to supply a port to connect to, set hostname as 'localhost:3306'.
 	$g_hostname				= 'localhost';
-	$g_port					= 3306;		 # 3306 is default
 	$g_db_username			= 'root';
 	$g_db_password			= '';
 	$g_database_name		= 'bugtracker';
@@ -177,7 +181,7 @@
 
 	# allow email notification
 	#  note that if this is disabled, sign-up and password reset messages will
-	#  not be sent.  
+	#  not be sent.
 	$g_enable_email_notification	= ON;
 
 	# The following two config options allow you to control who should get email
@@ -202,8 +206,8 @@
  	#         'deleted': a bug has been deleted
 	#         'updated': a bug has been updated
 	#         'bugnote': a bugnote has been added to a bug
-	#         'sponsor': sponsorship has changed on this bug 
-	#        'relation': a relationship has changed on this bug 
+	#         'sponsor': sponsorship has changed on this bug
+	#        'relation': a relationship has changed on this bug
 	#        '<status>': eg: 'resolved', 'closed', 'feedback', 'acknowledged', ...etc.
 	#                     this list corresponds to $g_status_enum_string
 
@@ -294,7 +298,7 @@
 	#############################
 
 	# --- version variables -----------
-	$g_mantis_version		= '0.19.0';
+	$g_mantis_version		= '0.19.2';
 	$g_show_version			= ON;
 
 	################################
@@ -310,12 +314,41 @@
 
 	# list the choices that the users are allowed to choose
 	$g_language_choices_arr	= array(
-		'auto', 'english', 'chinese_simplified', 'chinese_traditional', 'czech',
-		'danish', 'dutch', 'estonian', 'french', 'german', 'hungarian',
-		'italian', 'japanese_euc', 'japanese_sjis', 'japanese_utf8', 'korean', 
-		'lithuanian', 'norwegian', 'polish', 'portuguese_brazil', 'portuguese_standard',
-		'romanian', 'russian', 'russian_koi8', 'serbian', 'slovak', 'slovene', 
-		'spanish', 'swedish', 'turkish' );
+		'auto',
+		'chinese_simplified',
+		'chinese_traditional',
+		'croatian',
+		'czech',
+		'danish',
+		'dutch',
+		'english',
+		'estonian',
+		'finnish',
+		'french',
+		'german',
+		'hungarian',
+		'italian',
+		'japanese_euc',
+		'japanese_sjis',
+		'japanese_utf8',
+		'korean',
+		'latvian',
+		'lithuanian',
+		'norwegian',
+		'polish',
+		'portuguese_brazil',
+		'portuguese_standard',
+		'romanian',
+		'russian',
+		'russian_koi8',
+		'serbian',
+		'slovak',
+		'slovene',
+		'spanish',
+		'swedish',
+		'turkish',
+		'ukrainian'
+	);
 
 	# Browser language mapping for 'auto' language selection
 	$g_language_auto_map = array(
@@ -326,6 +359,7 @@
 		'da' => 'danish',
 		'nl-be, nl' => 'dutch',
 		'et' => 'estonian',
+		'fi' => 'finnish',
 		'fr-be, fr-ca, fr-ch, fr' => 'french',
 		'de-de, de-at, de-ch, de' => 'german',
 		'hu' => 'hungarian',
@@ -347,7 +381,7 @@
 		'tr' => 'turkish'
 	);
 
-	# Fallback for automatic language selection 
+	# Fallback for automatic language selection
 	$g_fallback_language	= 'english';
 
 	###############################
@@ -514,15 +548,15 @@
 	$g_default_email_on_bugnote		= ON;
 	$g_default_email_on_status		= 0; # @@@ Unused
 	$g_default_email_on_priority	= 0; # @@@ Unused
-	$g_default_email_on_new_minimum_severity		= 'any';
-	$g_default_email_on_assigned_minimum_severity	= 'any';
-	$g_default_email_on_feedback_minimum_severity	= 'any';
-	$g_default_email_on_resolved_minimum_severity	= 'any';
-	$g_default_email_on_closed_minimum_severity		= 'any';
-	$g_default_email_on_reopened_minimum_severity	= 'any';
-	$g_default_email_on_bugnote_minimum_severity	= 'any';
-	$g_default_email_on_status_minimum_severity		= 'any'; # @@@ Unused
-	$g_default_email_on_priority_minimum_severity	= 'any'; # @@@ Unused
+	$g_default_email_on_new_minimum_severity		= OFF; # 'any'
+	$g_default_email_on_assigned_minimum_severity	= OFF; # 'any'
+	$g_default_email_on_feedback_minimum_severity	= OFF; # 'any'
+	$g_default_email_on_resolved_minimum_severity	= OFF; # 'any'
+	$g_default_email_on_closed_minimum_severity		= OFF; # 'any'
+	$g_default_email_on_reopened_minimum_severity	= OFF; # 'any'
+	$g_default_email_on_bugnote_minimum_severity	= OFF; # 'any'
+	$g_default_email_on_status_minimum_severity		= OFF; # @@@ Unused
+	$g_default_email_on_priority_minimum_severity	= OFF; # @@@ Unused
 	$g_default_email_bugnote_limit					= 0;
 	# default_language - is set to site language
 
@@ -717,17 +751,17 @@
 	# the bug is in progress, rather than just put in a person's queue.
 	$g_auto_set_status_to_assigned	= ON;
 
-	# 'status_enum_workflow' defines the workflow, and reflects a simple 
+	# 'status_enum_workflow' defines the workflow, and reflects a simple
 	#  2-dimensional matrix. For each existing status, you define which
-	#  statuses you can go to from that status, e.g. from NEW_ you might list statuses 
+	#  statuses you can go to from that status, e.g. from NEW_ you might list statuses
 	#  '10:new,20:feedback,30:acknowledged' but not higher ones.
 	# The following example can be transferred to config_inc.php
-	# $g_status_enum_workflow[NEW_]='10:new,20:feedback,30:acknowledged,40:confirmed,50:assigned,80:resolved';
-	# $g_status_enum_workflow[FEEDBACK] ='10:new,20:feedback,30:acknowledged,40:confirmed,50:assigned,80:resolved';
-	# $g_status_enum_workflow[ACKNOWLEDGED] ='20:feedback,30:acknowledged,40:confirmed,50:assigned,80:resolved';
-	# $g_status_enum_workflow[CONFIRMED] ='20:feedback,40:confirmed,50:assigned,80:resolved';
-	# $g_status_enum_workflow[ASSIGNED] ='20:feedback,50:assigned,80:resolved,90:closed';
-	# $g_status_enum_workflow[RESOLVED] ='50:assigned,80:resolved,90:closed';
+	# $g_status_enum_workflow[NEW_]='20:feedback,30:acknowledged,40:confirmed,50:assigned,80:resolved';
+	# $g_status_enum_workflow[FEEDBACK] ='10:new,30:acknowledged,40:confirmed,50:assigned,80:resolved';
+	# $g_status_enum_workflow[ACKNOWLEDGED] ='20:feedback,40:confirmed,50:assigned,80:resolved';
+	# $g_status_enum_workflow[CONFIRMED] ='20:feedback,50:assigned,80:resolved';
+	# $g_status_enum_workflow[ASSIGNED] ='20:feedback,80:resolved,90:closed';
+	# $g_status_enum_workflow[RESOLVED] ='50:assigned,90:closed';
 	# $g_status_enum_workflow[CLOSED] ='50:assigned';
 	$g_status_enum_workflow = array();
 
@@ -780,6 +814,8 @@
 	$g_report_bug_threshold			= REPORTER;
 
 	# access level needed to update bugs (i.e., the update_bug_page)
+	#  This controls whether the user sees the "Update Bug" button in bug_view*_page
+	#  and the pencil icon in view_all_bug_page
 	$g_update_bug_threshold			= UPDATER;
 
 	# access level needed to monitor bugs
@@ -792,6 +828,11 @@
 
 	# access level needed to be able to be listed in the assign to field.
 	$g_handle_bug_threshold			= DEVELOPER;
+	# access level needed to show the Assign To: button bug_view*_page or
+	#  the Assigned list in bug_update*_page.
+	#  This allows control over who can route bugs
+	# This defaults to $g_handle_bug_threshold
+	# $g_update_bug_assign_threshold			= DEVELOPER;
 
 	# access level needed to view private bugnotes
 	# Look in the constant_inc.php file if you want to set a different value
@@ -887,7 +928,7 @@
 	# Threshold needed to be able to create shared stored queries
 	$g_stored_query_create_shared_threshold = MANAGER;
 
-	# Threshold needed to update readonly bugs.  Readonly bugs are identified via 
+	# Threshold needed to update readonly bugs.  Readonly bugs are identified via
 	# $g_bug_readonly_status_threshold.
 	$g_update_readonly_bug_threshold = MANAGER;
 
@@ -897,11 +938,14 @@
 	# status change thresholds
 	$g_update_bug_status_threshold = DEVELOPER;
 
+	# access level needed to re-open bugs
+	$g_reopen_bug_threshold			= DEVELOPER;
+
 	# this array sets the access thresholds needed to enter each status listed.
 	# if a status is not listed, it falls back to $g_update_bug_status_threshold
 	# example: $g_set_status_threshold = array( ACKNOWLEDGED => MANAGER, CONFIRMED => DEVELOPER, CLOSED => MANAGER );
 	$g_set_status_threshold = array();
-	
+
 	# --- login method ----------------
 	# CRYPT or PLAIN or MD5 or LDAP or BASIC_AUTH
 	# You can simply change this at will. Mantis will try to figure out how the passwords were encrypted.
@@ -940,9 +984,9 @@
 	# insert the URL to your CVSweb or ViewCVS
 	# eg: http://cvs.sourceforge.net/cgi-bin/viewcvs.cgi/mantisbt/mantisbt/
 	$g_cvs_web				= '';
-	
+
 	# --- Source Control Integration ------
-	
+
 	# For open source projects it is expected that the notes be public, however,
 	# for non-open source it will probably be VS_PRIVATE.
 	$g_source_control_notes_view_status = VS_PRIVATE;
@@ -952,7 +996,7 @@
 	# private ones (DEVELOPER access recommended).
 	$g_source_control_account           = '';
 
-	# If set to a status, then after a checkin, the issue status is set to the 
+	# If set to a status, then after a checkin, the issue status is set to the
 	# specified status, otherwise if set to OFF, the issue status is not affected.
 	$g_source_control_set_status_to     = OFF;
 
@@ -967,6 +1011,12 @@
 	# eg. for bug: a link would be bug:98
 	$g_bug_link_tag			= '#';
 
+	# --- Bugnote Linking ---------------
+	# if a number follows this tag it will create a link to a bugnote.
+	# eg. for ~ a link would be ~45
+	# eg. for bugnote: a link would be bugnote:98
+	$g_bugnote_link_tag			= '~';
+
 	# --- Bug Count Linking ----------
 	# this is the prefix to use when creating links to bug views from bug counts (eg. on the main
 	# page and the summary page).
@@ -990,6 +1040,10 @@
 	# the manage users page takes a long time.
 	$g_default_manage_user_prefix = 'ALL';
 
+	# --- CSV Export ---------------
+	# Set the csv separator
+	$g_csv_separator = ',';
+
 	################################
 	# Mantis Look and Feel Variables
 	################################
@@ -1038,6 +1092,7 @@
 	$g_view_all_cookie		= $g_cookie_prefix.'_VIEW_ALL_COOKIE';
 	$g_manage_cookie		= $g_cookie_prefix.'_MANAGE_COOKIE';
 	$g_logout_cookie		= $g_cookie_prefix.'_LOGOUT_COOKIE';
+	$g_bug_list_cookie		= $g_cookie_prefix.'_BUG_LIST_COOKIE';
 
 	#######################################
 	# Mantis Filter Variables
@@ -1098,7 +1153,7 @@
 	$g_status_enum_string				= '10:new,20:feedback,30:acknowledged,40:confirmed,50:assigned,80:resolved,90:closed';
 	  # @@@ for documentation, the values in this list are also used to define variables in the language files
 	  #  (e.g., $s_new_bug_title referenced in bug_change_status_page.php )
-	  # Embedded spaces are converted to underscores (e.g., "working on" references $s_working_on_bug_title). 
+	  # Embedded spaces are converted to underscores (e.g., "working on" references $s_working_on_bug_title).
 	  # they are also expected to be english names for the states
 	$g_resolution_enum_string			= '10:open,20:fixed,30:reopened,40:unable to duplicate,50:not fixable,60:duplicate,70:not a bug,80:suspended,90:wont fix';
 	$g_projection_enum_string			= '10:none,30:tweak,50:minor fix,70:major rework,90:redesign';
@@ -1197,6 +1252,31 @@
 	# need it for debugging
 	$g_show_detailed_errors	= OFF;
 
+	# --- error display ---
+	# what errors are displayed and how?
+	# The options for display are:
+	#  'halt' - stop and display traceback
+	#  'inline' - display 1 line error and continue
+	#  'none' - no error displayed
+	# obsoletes $g_show_notices (E_NOTICE and E_USER_NOTICE) and
+	#   $g_show_warnings (E_WARNING and E_USER_WARNING)
+	# A developer might set this in config_inc.php as:
+	#	$g_display_errors = array(
+	#		E_WARNING => 'halt',
+	#		E_NOTICE => 'halt',
+	#		E_USER_ERROR => 'halt',
+	#		E_USER_WARNING => 'none',
+	#		E_USER_NOTICE => 'none'
+	#	);
+
+	$g_display_errors = array(
+		E_WARNING => 'none',
+		E_NOTICE => 'none',
+		E_USER_ERROR => 'halt',
+		E_USER_WARNING => 'none',
+		E_USER_NOTICE => 'none'
+	);
+
 	# --- notice display ---
 	# Control whether errors of level NOTICE, the lowest level of error,
 	#  are displayed to the user.  Default is OFF, but turning it ON may
@@ -1321,7 +1401,7 @@
 		'recent_mod'	=> '5',
 		'monitored'	=> '6'
 	);
-	
+
 	# Toggle whether 'My View' boxes are shown in a fixed position (i.e. adjacent boxes start at the same vertical position)
 	$g_my_view_boxes_fixed_position = ON;
 
@@ -1335,4 +1415,63 @@
 	# Enable support for bug relationships where a bug can be a related, dependent on, or duplicate of another.
 	# See relationship_api.php for more details.
 	$g_enable_relationship = ON;
+
+	# --- Relationship Graphs -----------
+	# Show issue relationships using graphs.
+	#
+	# In order to use this feature, you must first install either GraphViz
+	# (all OSs except Windows) or WinGraphviz (only Windows).
+	#
+	# Graphviz homepage:    http://www.research.att.com/sw/tools/graphviz/
+	# WinGraphviz homepage: http://home.so-net.net.tw/oodtsen/wingraphviz/
+	#
+	# Refer to the notes near the top of core/graphviz_api.php and
+	# core/relationship_graph_api.php for more information.
+
+	# Enable relationship graphs support.
+	$g_relationship_graph_enable		= OFF;
+
+	# Font name and size, as required by Graphviz. If Graphviz fails to run
+	# for you, you are probably using a font name that gd can't find. On
+	# Linux, try the name of the font file without the extension.
+	$g_relationship_graph_fontname		= 'Arial';
+	$g_relationship_graph_fontsize		= 8;
+
+	# Local path where the above font is found on your system.
+	#
+	# You shouldn't care about this on Windows since there is only one system
+	# folder where fonts are installed and Graphviz already knows where it
+	# is. On Linux and other unices, the default font search path is defined
+	# during Graphviz compilation. If you are using a pre-compiled Graphviz
+	# package provided by your distribution, probably the font search path was
+	# already configured by the packager.
+	#
+	# If for any reason, the font file you want to use is not in any directory
+	# listed on the default font search path list, you can either: (1) export
+	# the DOTFONTPATH environment variable in your webserver startup script
+	# or (2) use this config option conveniently available here. If you need
+	# to list more than one directory, use colons to separate them.
+	$g_relationship_graph_fontpath		= '';
+
+	# Default dependency orientation. If you have issues with lots of childs
+	# or parents, leave as 'horizontal', otherwise, if you have lots of
+	# "chained" issue dependencies, change to 'vertical'.
+	$g_relationship_graph_orientation	= 'horizontal';
+
+	# Max depth for relation graphs. This only affects relation graphs,
+	# dependency graphs are drawn to the full depth. A value of 3 is already
+	# enough to show issues really unrelated to the one you are currently
+	# viewing.
+	$g_relationship_graph_max_depth		= 2;
+
+	# If set to ON, clicking on an issue on the relationship graph will open
+	# the bug view page for that issue, otherwise, will navigate to the
+	# relationship graph for that issue.
+	$g_relationship_graph_view_on_click	= OFF;
+
+	# Complete path to dot and neato tools. Your webserver must have execute
+	# permission to these programs in order to generate relationship graphs.
+	# NOTE: These are meaningless under Windows! Just ignore them!
+	$g_dot_tool							= '/usr/bin/dot';
+	$g_neato_tool						= '/usr/bin/neato';
 ?>
\ No newline at end of file
