@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: custom_field_api.php,v 1.41 2004/08/27 23:05:33 prichards Exp $
+	# $Id: custom_field_api.php,v 1.43 2004/11/17 20:01:34 prichards Exp $
 	# --------------------------------------------------------
 
 	$t_core_dir = dirname( __FILE__ ).DIRECTORY_SEPARATOR;
@@ -1150,7 +1150,7 @@
 				return str_replace( '|', ', ', $t_custom_field_value );
 				break;
 			default:
-				return $t_custom_field_value;
+				return string_display_links( $t_custom_field_value );
 		}	
 	}
 
