@@ -6,12 +6,13 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: filter_api.php,v 1.57 2004/08/21 13:07:14 prichards Exp $
+	# $Id: filter_api.php,v 1.64 2004/11/19 13:06:29 vboctor Exp $
 	# --------------------------------------------------------
 
 	$t_core_dir = dirname( __FILE__ ).DIRECTORY_SEPARATOR;
 
 	require_once( $t_core_dir . 'current_user_api.php' );
+	require_once( $t_core_dir . 'user_api.php' );
 	require_once( $t_core_dir . 'bug_api.php' );
 	require_once( $t_core_dir . 'collapse_api.php' );
 
@@ -37,7 +38,13 @@
 	# $p_bug_count
 	#   - you don't need to give a value here, the number of bugs will be
 	#     stored here on return
-	function filter_get_bug_rows( &$p_page_number, &$p_per_page, &$p_page_count, &$p_bug_count, $custom_filter = null ) {
+	# $p_custom_filter
+	#   - Filter to use.
+	# $p_project_id
+	#   - project id to use in filtering.
+	# $p_user_id
+	#   - user id to use as current user when filtering.
+	function filter_get_bug_rows( &$p_page_number, &$p_per_page, &$p_page_count, &$p_bug_count, $custom_filter = null, $p_project_id = null, $p_user_id = null ) {
 		$t_bug_table			= config_get( 'mantis_bug_table' );
 		$t_bug_text_table		= config_get( 'mantis_bug_text_table' );
 		$t_bugnote_table		= config_get( 'mantis_bugnote_table' );
@@ -48,11 +55,34 @@
 		$t_limit_reporters		= config_get( 'limit_reporters' );
 		$t_report_bug_threshold		= config_get( 'report_bug_threshold' );
 
+		$t_current_user_id = auth_get_current_user_id();
+		
+		if ( null === $p_user_id ) {
+			$t_user_id = $t_current_user_id;
+		} else {
+			$t_user_id = $p_user_id;
+		}
+		
+		$c_user_id = db_prepare_int( $t_user_id );
+
+		if ( null === $p_project_id ) {
+			$t_project_id	= helper_get_current_project();
+		} else {
+			$t_project_id	= $p_project_id;
+		}
+
 		if ( $custom_filter == null ) {
-			$t_filter = current_user_get_bug_filter();
+			# Prefer current_user_get_bug_filter() over user_get_filter() when applicable since it supports
+			# cookies set by previous version of the code.
+			if ( $t_user_id == $t_current_user_id ) {
+				$t_filter = current_user_get_bug_filter();
+			} else {
+				$t_filter = user_get_bug_filter( $t_user_id, $t_project_id );
+			}
 		} else {
 			$t_filter = $custom_filter;
 		}
+
 		$t_filter = filter_ensure_valid_filter( $t_filter );
 
 		if ( false === $t_filter ) {
@@ -60,17 +90,14 @@
 			#@@@ error instead?
 		}
 
-		$t_project_id	= helper_get_current_project();
-		$t_user_id		= auth_get_current_user_id();
-
 		$t_where_clauses = array( "$t_project_table.enabled = 1", "$t_project_table.id = $t_bug_table.project_id" );
 		$t_select_clauses = array( "$t_bug_table.*" );
 		$t_join_clauses = array();
 		$t_from_clauses = array();
 
 		if ( ALL_PROJECTS == $t_project_id ) {
-			if ( !current_user_is_administrator() ) {
-				$t_projects = current_user_get_accessible_projects();
+			if ( !user_is_administrator( $t_user_id ) ) {
+				$t_projects = user_get_accessible_projects( $t_user_id );
 
 				if ( 0 == count( $t_projects ) ) {
 					return array();  # no accessible projects, return an empty array
@@ -86,13 +113,13 @@
 				}
 			}
 		} else {
-			access_ensure_project_level( VIEWER, $t_project_id );
+			access_ensure_project_level( VIEWER, $t_project_id, $t_user_id );
 
 			array_push( $t_where_clauses, "($t_bug_table.project_id='$t_project_id')" );
 		}
 
 		# private bug selection
-		if ( !access_has_project_level( config_get( 'private_bug_threshold' ) ) ) {
+		if ( !access_has_project_level( config_get( 'private_bug_threshold' ), $t_project_id, $t_user_id ) ) {
 			$t_public = VS_PUBLIC;
 			array_push( $t_where_clauses, "($t_bug_table.view_state='$t_public' OR $t_bug_table.reporter_id='$t_user_id')" );
 		} else {
@@ -119,8 +146,8 @@
 			foreach( $t_filter['reporter_id'] as $t_filter_member ) {
 				$c_reporter_id = db_prepare_int( $t_filter_member );
 				if ( META_FILTER_MYSELF == $c_reporter_id ) {
-					if ( access_has_project_level( config_get( 'report_bug_threshold' ) ) ) {
-						$c_reporter_id = auth_get_current_user_id();
+					if ( access_has_project_level( config_get( 'report_bug_threshold' ), $t_project_id, $t_user_id ) ) {
+						$c_reporter_id = $c_user_id;
 						array_push( $t_clauses, "($t_bug_table.reporter_id='$c_reporter_id')" );
 					}
 				} else {
@@ -131,8 +158,8 @@
 		}
 
 		# limit reporter
-		if ( ( ON === $t_limit_reporters ) && ( current_user_get_access_level() <= $t_report_bug_threshold ) ) {
-			$c_reporter_id = db_prepare_int( auth_get_current_user_id() );
+		if ( ( ON === $t_limit_reporters ) && ( user_get_access_level( $t_user_id ) <= $t_report_bug_threshold ) ) {
+			$c_reporter_id = $c_user_id;
 			array_push( $t_where_clauses, "($t_bug_table.reporter_id='$c_reporter_id')" );
 		}
 
@@ -159,8 +186,8 @@
 				} else {
 					$c_handler_id = db_prepare_int( $t_filter_member );
 					if ( META_FILTER_MYSELF == $c_handler_id ) {
-						if ( access_has_project_level( config_get( 'handle_bug_threshold' ) ) ) {
-							$c_handler_id = auth_get_current_user_id();
+						if ( access_has_project_level( config_get( 'handle_bug_threshold' ), $t_project_id, $t_user_id ) ) {
+							$c_handler_id = $c_user_id;
 							if ( 'on' != $t_filter['and_not_assigned'] ) {
 								array_push( $t_clauses, "($t_bug_table.handler_id='$c_handler_id')" );
 							} else {
@@ -293,6 +320,27 @@
 			array_push( $t_where_clauses, '('. implode( ' OR ', $t_clauses ) .')' );
 		}
 
+		# priority 
+		$t_any_found = false;
+		foreach( $t_filter['show_priority'] as $t_filter_member ) {
+				if ( 'any' == $t_filter_member ) {
+						$t_any_found = true;
+				}
+		}
+		if ( count( $t_filter['show_priority'] ) == 0 ) {
+				$t_any_found = true;
+		}
+		if ( !$t_any_found ) {
+				$t_clauses = array();
+
+				foreach( $t_filter['show_priority'] as $t_filter_member ) {
+						$c_show_priority = db_prepare_int( $t_filter_member );
+						array_push( $t_clauses, "($t_bug_table.priority='$c_show_priority')" );
+				}
+				array_push( $t_where_clauses, '('. implode( ' OR ', $t_clauses ) .')' );
+		}
+
+
 		# product build
 		$t_any_found = false;
 		foreach( $t_filter['show_build'] as $t_filter_member ) {
@@ -388,8 +436,8 @@
 			foreach( $t_filter['user_monitor'] as $t_filter_member ) {
 				$c_user_monitor = db_prepare_int( $t_filter_member );
 				if ( META_FILTER_MYSELF == $c_user_monitor ) {
-					if ( access_has_project_level( config_get( 'monitor_bug_threshold' ) ) ) {
-						$c_user_monitor = auth_get_current_user_id();
+					if ( access_has_project_level( config_get( 'monitor_bug_threshold' ), $t_project_id, $t_user_id ) ) {
+						$c_user_monitor = $c_user_id;
 						array_push( $t_clauses, "($t_table_name.user_id='$c_user_monitor')" );
 					}
 				} else {
@@ -402,11 +450,11 @@
 		# custom field filters
 		if( ON == config_get( 'filter_by_custom_fields' ) ) {
 			# custom field filtering
-			$t_custom_fields = custom_field_get_ids();
+			$t_custom_fields = custom_field_get_ids();	# @@@@ Shouldn't the filter be on project specific custom fields?
 
 			foreach( $t_custom_fields as $t_cfid ) {
-			$t_first_time = true;
-			$t_custom_where_clause = '';
+				$t_first_time = true;
+				$t_custom_where_clause = '';
 				# Ignore all custom filters that are not set, or that are set to '' or "any"
 				$t_any_found = false;
 				foreach( $t_filter['custom_fields'][$t_cfid] as $t_filter_member ) {
@@ -424,7 +472,7 @@
 					foreach( $t_filter['custom_fields'][$t_cfid] as $t_filter_member ) {
 						if ( isset( $t_filter_member ) &&
 							( 'any' != strtolower( $t_filter_member ) ) &&
-							( !is_blank( trim( $t_filter_member ) ) ) ) {
+							( !is_blank( trim( $t_filter_member ) ) ) ) {	# @@@ What if the user wants to filter on issues with an empty custom field??.. tricky!!!
 
 							if( $t_first_time ) {
 								$t_first_time = false;
@@ -455,15 +503,25 @@
 			}
 		}
 
-		# Simple Text Search - Thnaks to Alan Knowles
+		$t_textsearch_where_clause = '';
+		$t_textsearch_wherejoin_clause = '';
+		# Simple Text Search - Thanks to Alan Knowles
 		if ( !is_blank( $t_filter['search'] ) ) {
 			$c_search = db_prepare_string( $t_filter['search'] );
-			array_push( $t_where_clauses,
-							"((summary LIKE '%$c_search%')
+			$c_search_int = db_prepare_int( $t_filter['search'] );
+			$t_textsearch_where_clause = "((summary LIKE '%$c_search%')
 							 OR ($t_bug_text_table.description LIKE '%$c_search%')
 							 OR ($t_bug_text_table.steps_to_reproduce LIKE '%$c_search%')
 							 OR ($t_bug_text_table.additional_information LIKE '%$c_search%')
-							 OR ($t_bug_table.id LIKE '%$c_search%'))" );
+							 OR ($t_bug_table.id = '$c_search_int'))";
+
+			$t_textsearch_wherejoin_clause = "((summary LIKE '%$c_search%')
+							 OR ($t_bug_text_table.description LIKE '%$c_search%')
+							 OR ($t_bug_text_table.steps_to_reproduce LIKE '%$c_search%')
+							 OR ($t_bug_text_table.additional_information LIKE '%$c_search%')
+							 OR ($t_bug_table.id LIKE '%$c_search%')
+							 OR ($t_bugnote_text_table.note LIKE '%$c_search%'))";
+							 
 			array_push( $t_where_clauses, "($t_bug_text_table.id = $t_bug_table.bug_text_id)" );
 
 			$t_from_clauses = array( $t_bug_text_table, $t_project_table, $t_bug_table );
@@ -481,10 +539,46 @@
 			$t_where	= '';
 		}
 
+		# Possibly do two passes. First time, grab the IDs of issues that match the filters. Second time, grab the IDs of issues that
+		# have bugnotes that match the text search if necessary.
+		$t_id_array = array();
+		for ( $i = 0; $i < 2; $i++ ) {
+			$t_id_where = $t_where;
+			$t_id_join = $t_join;
+			if ( $i == 0 ) {
+				if ( !is_blank( $t_id_where ) && !is_blank( $t_textsearch_where_clause ) ) {
+					$t_id_where = $t_id_where . ' AND ' . $t_textsearch_where_clause;
+				}
+			} else if ( !is_blank( $t_textsearch_wherejoin_clause ) ) {
+				$t_id_where = $t_id_where . ' AND ' . $t_textsearch_wherejoin_clause;
+				$t_id_join = $t_id_join . " INNER JOIN $t_bugnote_table ON $t_bugnote_table.bug_id = $t_bug_table.id";
+				$t_id_join = $t_id_join . " INNER JOIN $t_bugnote_text_table ON $t_bugnote_text_table.id = $t_bugnote_table.bugnote_text_id";
+			}
+			$query  = "SELECT DISTINCT $t_bug_table.id
+						$t_from
+						$t_id_join
+						$t_id_where";
+			if ( ( $i == 0 ) || ( !is_blank( $t_textsearch_wherejoin_clause ) ) ) {
+				$result = db_query( $query );
+				$row_count = db_num_rows( $result );
+
+				for ( $j=0; $j < $row_count; $j++ ) {
+					$row = db_fetch_array( $result );
+					$t_id_array[] = db_prepare_int ( $row['id'] );
+				}
+			}
+		}
+
+		$t_id_array = array_unique( $t_id_array );
+		if ( count( $t_id_array ) > 0 ) {
+			$t_where = "WHERE $t_bug_table.id = " . implode( " OR $t_bug_table.id = ", $t_id_array );
+		} else {
+			$t_where = "WHERE 1 != 1";
+		}
+		$t_from = 'FROM ' . $t_bug_table;
+
 		# Get the total number of bugs that meet the criteria.
-		$query = "SELECT COUNT( DISTINCT $t_bug_table.id ) as count $t_from $t_join $t_where";
-		$result = db_query( $query );
-		$bug_count = db_result( $result );
+		$bug_count = count( $t_id_array );
 
 		# write the value back in case the caller wants to know
 		$p_bug_count = $bug_count;
@@ -650,13 +744,14 @@
 		$t_tdclass = 'small-caption';
 		$t_trclass = 'row-category2';
 		$t_action  = 'view_all_set.php?f=3';
-
+		
 		if ( $p_for_screen == false ) {
 			$t_tdclass = 'print';
 			$t_trclass = '';
 			$t_action  = 'view_all_set.php';
 		}
-?>
+?> 
+
 		<br />
 		<form method="post" name="filters" action="<?php PRINT $t_action; ?>">
 		<input type="hidden" name="type" value="5" />
@@ -671,7 +766,7 @@
 		<input type="hidden" name="page_number" value="<?php PRINT $p_page_number ?>" />
 		<input type="hidden" name="view_type" value="<?php PRINT $t_view_type ?>" />
 		<table class="width100" cellspacing="1">
-
+		
 		<?php
 		if ( $p_expanded ) {
 			$t_filter_cols = 7;
@@ -963,9 +1058,12 @@
 			<td colspan="2" class="small-caption" valign="top">
 				<a href="<?php PRINT $t_filters_url . 'show_version[]'; ?>"><?php PRINT lang_get( 'product_version' ) ?>:</a>
 			</td>
-			<td colspan="2" class="small-caption" valign="top">
+			<td colspan="1" class="small-caption" valign="top">
 				<a href="<?php PRINT $t_filters_url . 'fixed_in_version[]'; ?>"><?php PRINT lang_get( 'fixed_in_version' ) ?>:</a>
 			</td>
+			<td colspan="1" class="small-caption" valign="top">
+                                <a href="<?php PRINT $t_filters_url . 'show_priority[]'; ?>"><?php PRINT lang_get( 'priority' ) ?>:</a>
+                        </td>
 		</tr>
 
 		<tr class="row-1">
@@ -1093,7 +1191,7 @@
 								}
 							?>
 			</td>
-			<td colspan="2" class="small-caption" valign="top">
+			<td colspan="1" class="small-caption" valign="top">
 							<?php
 								$t_output = '';
 								$t_any_found = false;
@@ -1123,6 +1221,36 @@
 								}
 							?>
 			</td>
+			<td colspan="1" class="small-caption" valign="top">
+                                                        <?php
+							        $t_output = '';
+                                                                $t_any_found = false;
+                                                                if ( count( $t_filter['show_priority'] ) == 0 ) {
+                                                                        PRINT lang_get( 'any' );
+                                                                } else {
+                                                                        $t_first_flag = true;
+                                                                        foreach( $t_filter['show_priority'] as $t_current ) {
+                                                                                $t_this_string = '';
+                                                                                if ( ( $t_current == 'any' ) || ( is_blank( $t_current ) ) ) {
+                                                                                        $t_any_found = true;
+                                                                                } else {
+                                                                                        $t_this_string = get_enum_element( 'priority', $t_current );
+                                                                                }
+                                                                                if ( $t_first_flag != true ) {
+                                                                                        $t_output = $t_output . '<br>';
+                                                                                } else {
+                                                                                        $t_first_flag = false;
+                                                                                }
+                                                                                $t_output = $t_output . $t_this_string;
+                                                                        }
+                                                                        if ( true == $t_any_found ) {
+                                                                                PRINT lang_get( 'any' );
+                                                                        } else {
+                                                                                PRINT $t_output;
+                                                                        }
+                                                                }
+                                                        ?>
+                        </td>
 		</tr>
 
 		<tr <?php PRINT "class=\"" . $t_trclass . "\""; ?>>
@@ -1451,7 +1579,7 @@
 	# tied to the unique id parameter. If the user doesn't
 	# have permission to see this filter, the function will
 	# return null
-	function filter_db_get_filter( $p_filter_id ) {
+	function filter_db_get_filter( $p_filter_id, $p_user_id = null ) {
 		global $g_cache_filter_db_filters;
 		$t_filters_table = config_get( 'mantis_filters_table' );
 		$c_filter_id = db_prepare_int( $p_filter_id );
@@ -1459,6 +1587,12 @@
 		if ( isset( $g_cache_filter_db_filters[$p_filter_id] ) ) {
 			return $g_cache_filter_db_filters[$p_filter_id];
 		}
+		
+		if ( null === $p_user_id ) {
+			$t_user_id = auth_get_current_user_id();
+		} else {
+			$t_user_id = $p_user_id;
+		}
 
 		$query = "SELECT *
 				  FROM $t_filters_table
@@ -1468,14 +1602,14 @@
 		if ( db_num_rows( $result ) > 0 ) {
 			$row = db_fetch_array( $result );
 
-			if ( $row['user_id'] != auth_get_current_user_id() ) {
+			if ( $row['user_id'] != $t_user_id ) {
 				if ( $row['is_public'] != true ) {
 					return null;
 				}
 			}
 
 			# check that the user has access to non current filters
-			if ( ( ALL_PROJECTS <= $row['project_id'] ) && ( !is_blank( $row['name'] ) ) && ( !access_has_project_level( config_get( 'stored_query_use_threshold' ) ) ) ) {
+			if ( ( ALL_PROJECTS <= $row['project_id'] ) && ( !is_blank( $row['name'] ) ) && ( !access_has_project_level( config_get( 'stored_query_use_threshold', $row['project_id'], $t_user_id ) ) ) ) {
 				return null;
 			}
 
@@ -1486,16 +1620,21 @@
 		return null;
 	}
 
-	function filter_db_get_project_current( $p_project_id ) {
+	function filter_db_get_project_current( $p_project_id, $p_user_id = null ) {
 		$t_filters_table = config_get( 'mantis_filters_table' );
 		$c_project_id 	= db_prepare_int( $p_project_id );
 		$c_project_id 	= $c_project_id * -1;
-		$t_user_id 		= auth_get_current_user_id();
+
+		if ( null === $p_user_id ) {
+			$c_user_id 		= auth_get_current_user_id();
+		} else {
+			$c_user_id		= db_prepare_int( $p_user_id );
+		}
 
 		# we store current filters for each project with a special project index
 		$query = "SELECT *
 				  FROM $t_filters_table
-				  WHERE user_id='$t_user_id'
+				  WHERE user_id='$c_user_id'
 				  	AND project_id='$c_project_id'
 				  	AND name=''";
 		$result = db_query( $query );
@@ -1588,11 +1727,21 @@
 		$result = db_query( $query );
 	}
 
-	function filter_db_get_available_queries( ) {
+	function filter_db_get_available_queries( $p_project_id = null, $p_user_id = null ) {
 		$t_filters_table = config_get( 'mantis_filters_table' );
 		$t_overall_query_arr = array();
-		$t_project_id = helper_get_current_project();
-		$t_user_id = auth_get_current_user_id();
+		
+		if ( null === $p_project_id ) {
+			$t_project_id = helper_get_current_project();
+		} else {
+			$t_project_id = db_prepare_int( $p_project_id );
+		}
+
+		if ( null === $p_user_id ) {
+			$t_user_id = auth_get_current_user_id();
+		} else {
+			$t_user_id = db_prepare_int( $p_user_id );
+		}
 
 		# If the user doesn't have access rights to stored queries, just return
 		if ( !access_has_project_level( config_get( 'stored_query_use_threshold' ) ) ) {
@@ -1695,6 +1844,7 @@
 									  'reporter_id' => 'int',
 									  'handler_id' => 'string',
 									  'show_resolution' => 'int',
+									  'show_priority' => 'int',
 									  'show_build' => 'string',
 									  'show_version' => 'string',
 									  'hide_status' => 'int',
