@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: file_download.php,v 1.28 2004/06/16 04:28:29 robertjf Exp $
+	# $Id: file_download.php,v 1.31 2004/12/08 16:52:42 thraxisp Exp $
 	# --------------------------------------------------------
 ?>
 <?php
@@ -65,7 +65,9 @@
 			access_ensure_project_level( config_get( 'view_proj_doc_threshold' ), $v_project_id );
 			break;
 	}
-	
+
+	# flush output buffer to protect download
+	@ob_end_clean();
 	# Make sure that IE can download the attachments under https.
 	header( 'Pragma: public' );
 	
@@ -75,6 +77,9 @@
 	# Added Quotes (") around file name.
 	header( 'Content-Disposition: filename="' . file_get_display_name( $v_filename ) . '"' );
 	header( 'Content-Description: Download Data' );
+	# prevent file caching @@@ (thraxisp) we may want to suppress this for small files
+	header( 'Pragma: no-cache' );
+	header( 'Expires: 0' );
 
 	# dump file content to the connection.
 	switch ( config_get( 'file_upload_method' ) ) {
@@ -88,7 +93,7 @@
 				readfile( $v_diskfile );
 			} else {
 				$ftp = file_ftp_connect();
-				file_ftp_get ( $ftp, $v_diskfile, $v_filename );
+				file_ftp_get ( $ftp, $v_diskfile, $v_diskfile );
 				file_ftp_disconnect( $ftp );
 				readfile( $v_diskfile );
 			}
@@ -96,4 +101,5 @@
 		default:
 			echo $v_content;
 	}
+	exit();
 ?>
