@@ -6,11 +6,11 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Revision: 1.54 $
-	# $Author: vboctor $
-	# $Date: 2004/07/20 15:51:50 $
+	# $Revision: 1.56 $
+	# $Author: thraxisp $
+	# $Date: 2004/10/17 00:14:27 $
 	#
-	# $Id: view_all_bug_page.php,v 1.54 2004/07/20 15:51:50 vboctor Exp $
+	# $Id: view_all_bug_page.php,v 1.56 2004/10/17 00:14:27 thraxisp Exp $
 	# --------------------------------------------------------
 ?>
 <?php
@@ -34,6 +34,13 @@
 		print_header_redirect( 'view_all_set.php?type=0' );
 	}
 
+	$t_bugslist = Array();
+	for($i=0; $i < sizeof( $rows ); $i++) {
+		array_push($t_bugslist, $rows[$i]["id"] );
+	}
+
+	gpc_set_cookie( config_get( 'bug_list_cookie' ), implode( ',', $t_bugslist ) );
+
 	compress_enable();
 
 	html_page_top1( lang_get( 'view_bugs_link' ) );
